summaryrefslogtreecommitdiffstats
path: root/include/llvm/CodeGen/PseudoSourceValue.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/llvm/CodeGen/PseudoSourceValue.h')
-rw-r--r--include/llvm/CodeGen/PseudoSourceValue.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/llvm/CodeGen/PseudoSourceValue.h b/include/llvm/CodeGen/PseudoSourceValue.h
index ce6b036..c6be645 100644
--- a/include/llvm/CodeGen/PseudoSourceValue.h
+++ b/include/llvm/CodeGen/PseudoSourceValue.h
@@ -47,9 +47,9 @@ namespace llvm {
return V->getValueID() == PseudoSourceValueVal;
}
- /// A pseudo source value referencing a stack frame entry,
- /// e.g., a spill slot or an incoming argument on stack.
- static const PseudoSourceValue *getStackObject(int FI);
+ /// A pseudo source value referencing a fixed stack frame entry,
+ /// e.g., a spill slot.
+ static const PseudoSourceValue *getFixedStack(int FI);
/// A pseudo source value referencing the area below the stack frame of
/// a function, e.g., the argument space.